@@ -17,7 +17,7 @@ $(document).ready(function() {
 			preview.scrollTop( (preview[0].scrollHeight - preview.height()) * percent );
 		});
 
-		$(this).find('preview').scroll(function(e) {
+		$(this).find('.preview').scroll(function(e) {
 			var percent = $(this).scrollTop() / ( $(this)[0].scrollHeight-$(this).height() );
 			var textarea = $(this).parent().parent().find('textarea');
 			textarea.scrollTop( (textarea[0].scrollHeight - textarea.height()) * percent );
